@@ -15,7 +15,7 @@ use Scalar::Util qw(blessed);
 our $GELF_SPEC_VERSION = '1.1';
 our $HOSTNAME = hostname();
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 
 
@@ -125,10 +125,12 @@ sub log {
 
     # preserve params, which are allowed by client
     # including some mispelled ones
-    $gelf{host}      = delete $gelf{_hostname}  if defined $gelf{_hostname};
-    $gelf{host}      = delete $gelf{_host}      if defined $gelf{_host};
-    $gelf{timestamp} = delete $gelf{_time}      if defined $gelf{_time};
-    $gelf{timestamp} = delete $gelf{_timestamp} if defined $gelf{_timestamp};
+    $gelf{host}         = delete $gelf{_hostname}       if defined $gelf{_hostname};
+    $gelf{host}         = delete $gelf{_host}           if defined $gelf{_host};
+    $gelf{timestamp}    = delete $gelf{_time}           if defined $gelf{_time};
+    $gelf{timestamp}    = delete $gelf{_timestamp}      if defined $gelf{_timestamp};
+    $gelf{full_message} = delete $gelf{_message}        if defined $gelf{_message};
+    $gelf{full_message} = delete $gelf{_full_message}   if defined $gelf{_full_message};
 
     # hostname defaults to system hostname...
     $gelf{host} //= $HOSTNAME;
@@ -168,7 +170,7 @@ Log::Radis - Radis is a graylog logging radio through a redis database
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -277,7 +279,7 @@ These levels are known and supposed to be compatible to various other logging en
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/zurborg/liblog-radis-perl/issues>
+https://github.com/zurborg/liblog-radis-perl/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
